@@ -7,7 +7,86 @@ from rest_framework.schemas.utils import is_list_view
 
 class BaseSchema(AutoSchema):
     def __init__(self, **kwargs):
+        """
+            customize_parameters: It is a list of dictionaries of fields available
+                in the path that we want to change the description;
+                e.g.:
+                    path('<str:field>', ContentDistinct.as_view()),
+                    customize_parameters = [
+                        {
+                            'name': 'field',
+                            'description': f'field (available options are:\
+                                            { available_options} '
+                        }
+                    ]
+
+            query_parameters: It is a list of dictionaries personalized query params;
+                e.g.:
+                    query_parameters=[
+                        {
+                            'name': 'url',
+                            'description': 'description',
+                            'required': True
+                        },
+                    ]
+
+            request_serializer: It is the serializer used to check if request is
+                valid. It is usually used with APIView and viewsets.ViewSet.
+                e.g.:
+                    request_serializer=FileSerializer
+
+            required_authorization: It is necessary to have authorization to
+                access the route. Future improvement: Add which kind of authorization
+                is required; It can be a boolean or a dictionary. The dictionary
+                is necessary when the GET has no authorization and other methods
+                has.
+                e.g:
+                    required_authorization={
+                        'get': False,
+                        'post': True
+                    }
+                e.g:
+                    required_authorization=True
+
+            required_locale: It is necessary to have locale;
+
+            required_software_type: It is necessary to have software type;
+
+            filter_fields: It is used to show the possible filters
+                in the query params; It can be used with: generics.ListAPIView and
+                viewsets.ModelViewSet; The fields needs to be available in the
+                model;
+                e.g.:
+                    filter_fields=[
+                        title', 'subtitle', 'locale'
+                    ]
+            sort_fields: It is used to show the possible sorting option
+                in the query params; It can be used with: generics.ListAPIView and
+                viewsets.ModelViewSet; The fields needs to be available in the
+                model;
+                e.g.:
+                    sort_fields=[
+                        'title', 'subtitle', 'locale'
+                    ]
+            responses: It is used to give the possible responses.
+                e.g.:
+                    responses={
+                        200: {
+                            'serializer': DocContentDistinctSerializer,
+                            'description': 'Returns the available options'
+                        },
+                        400: {
+                            'description': f'This field is not available for distinct. Available options are: {available_options}'
+                        }
+                    }
+            request_serializer_exception: It will be deprecated; It was necessary
+            because of the profile service and multiple version in the same view.
+
+            responses_exception: It will be deprecated; It was necessary
+            because of the profile service and multiple version in the same view.
+        """
         self.customize_parameters = kwargs.pop("customize_parameters", None)
+        self.query_parameters = kwargs.pop("query_parameters", None)
 
         self.request_serializer = kwargs.pop("request_serializer", None)
 
@@ -94,8 +173,8 @@ class BaseSchema(AutoSchema):
             return {}
 
         if self.request_serializer:
-            serializer = self.request_serializer
-            content = self.map_serializer(serializer())
+            serializer = self.request_serializer()
+            content = self.map_serializer(serializer)
 
         elif self.request_serializer_exception:
             for version in self.request_serializer_exception.keys():
@@ -288,6 +367,16 @@ class BaseSchema(AutoSchema):
                 'description': 'Options are: Web or Application or Backoffice. Example: Software-Type=Web.',
                 'schema': {'type': 'string'}
             }]
+
+        if self.query_parameters:
+            for query_param in self.query_parameters:
+                parameters += [{
+                    'name': query_param['name'],
+                    'in': 'query',
+                    'required': query_param['required'] if 'required' in query_param.keys() else False,
+                    'description': query_param['description'],
+                    'schema': {'type': 'string'}
+                }]
         return parameters
 
     def _custom_response(self, responses):
@@ -298,7 +387,7 @@ class BaseSchema(AutoSchema):
                 continue
 
             serializer = res['serializer']()
-            description = res['description'] if 'description' not in res.keys() else ''
+            description = res['description'] if 'description' in res.keys() else ''
             custom_response[status] = {
                 'content': {
                     'application/json': {
