@@ -1,6 +1,9 @@
 import hashlib
 
-def get_user_id_with_uid(user_hash, salt="3CD13NwnvxQmwc3WLaeE"):
+default_salt: str = "3CD13NwnvxQmwc3WLaeE"
+
+
+def get_user_id_with_uid(user_hash, salt=default_salt):
     """
       params: user_hash and salt
       return: user_id
@@ -16,3 +19,8 @@ def get_user_id_with_uid(user_hash, salt="3CD13NwnvxQmwc3WLaeE"):
         user_list[hash_object.hexdigest()] = str(i)
 
     return user_list[user_hash]
+
+
+def get_user_hash(id, salt=default_salt):
+    to_hash = str(id) + salt
+    return hashlib.md5(to_hash.encode('utf-8')).hexdigest()
